@@ -1,7 +1,7 @@
 from dj_rest_auth.serializers import UserDetailsSerializer
 from rest_framework import serializers
 
-from apps.accounts.models import Membership, Site, UserProfile
+from apps.accounts.models import Invitation, Membership, Site, UserProfile
 
 
 class UserProfileSerializer(serializers.ModelSerializer):
@@ -18,9 +18,17 @@ class UserSerializer(UserDetailsSerializer):
 
 
 class SiteSerializer(serializers.ModelSerializer):
+    created_by = UserDetailsSerializer(many=False, read_only=True)
+
     class Meta:
         model = Site
-        read_only_fields = ("id", "created_at", "created_by", "updated_at")
+        read_only_fields = (
+            "id",
+            "created_at",
+            "created_by",
+            "updated_at",
+            "status",
+        )
         fields = (
             "id",
             "created_at",
@@ -28,15 +36,31 @@ class SiteSerializer(serializers.ModelSerializer):
             "updated_at",
             "title",
             "slug",
+            "domain",
+            "custom_domain",
             "share",
+            "welcome",
             "active",
+            "status",
+            "info",
+            "domain",
         )
 
 
 class MembershipSerializer(serializers.ModelSerializer):
     user = UserDetailsSerializer(many=False, read_only=True)
+    created_by = UserDetailsSerializer(many=False, read_only=True)
 
     class Meta:
         model = Membership
         read_only_fields = ("id", "created_at", "created_by", "updated_at")
         fields = read_only_fields + ("rights", "user")
+
+
+class InvitationSerializer(serializers.ModelSerializer):
+    created_by = UserDetailsSerializer(many=False, read_only=True)
+
+    class Meta:
+        model = Invitation
+        read_only_fields = ("id", "invited", "created_at", "created_by", "rights")
+        fields = read_only_fields
