@@ -8,14 +8,11 @@ import threading
 import time
 from datetime import datetime
 
-from django_drf_filepond.models import TemporaryUpload
 from execnb.nbio import nb2dict, read_nb
-from matplotlib.pyplot import close
 
 from apps.nb.nbrun import NbRun
 from apps.nbworker.utils import Purpose, stop_event
 from apps.nbworker.ws import WSClient
-from apps.tasks.models import Task
 from apps.workers.models import WorkerState
 from apps.ws.utils import parse_params
 from widgets.manager import WidgetsManager
@@ -162,7 +159,6 @@ class NBWorker(WSClient):
             )
 
             if widget_type == "File" and len(value) == 2:
-                
                 log.debug(f"Get file {value[0]} from id={value[1]}")
                 # tu = TemporaryUpload.objects.get(upload_id=value[1])
                 # value[1] = tu.get_file_path()
@@ -180,7 +176,7 @@ class NBWorker(WSClient):
                 code = f'WidgetsManager.update("{widget_key}", field="value", new_value="{output_dir}")'
 
             elif isinstance(value, str):
-                code = f'WidgetsManager.update("{widget_key}", field="value", new_value="{value}")'
+                code = f'WidgetsManager.update("{widget_key}", field="value", new_value="""{value}""")'
             else:
                 code = f'WidgetsManager.update("{widget_key}", field="value", new_value={value})'
 
