@@ -1,11 +1,18 @@
 from django.conf.urls import include, url
 from rest_framework.routers import DefaultRouter
 
-from apps.tasks.views import (ClearTasksView, CreateRestAPITask,
-                              ExecutionHistoryView, ExportPDF, GetLastTaskView,
-                              GetPDFAddress, GetRestAPITask,
-                              ListOutputFilesView, ListWorkerOutputFilesView,
-                              TaskCreateView)
+from apps.tasks.views import (
+    ClearTasksView,
+    CreateRestAPITask,
+    ExecutionHistoryView,
+    ExportPDF,
+    GetLastTaskView,
+    GetPDFAddress,
+    GetRestAPITask,
+    ListOutputFilesView,
+    ListWorkerOutputFilesView,
+    TaskCreateView,
+)
 
 tasks_urlpatterns = [
     url("api/v1/execute/(?P<notebook_id>.+)", TaskCreateView.as_view()),
@@ -18,7 +25,7 @@ tasks_urlpatterns = [
         ListOutputFilesView.as_view(),
     ),
     url(
-        "api/v1/worker_output_files/(?P<session_id>.+)/(?P<worker_id>.+)",
+        "api/v1/worker-output-files/(?P<session_id>.+)/(?P<worker_id>.+)/(?P<notebook_id>.+)",
         ListWorkerOutputFilesView.as_view(),
     ),
     url(
