@@ -7,18 +7,20 @@ from .manager import WidgetException, WidgetsManager
 
 
 class Button:
-    def __init__(self, label="", style="primary"):
+    def __init__(self, label="", style="primary", disabled=False, hidden=False):
         self.code_uid = WidgetsManager.get_code_uid("Button")
 
         if style not in ["primary", "success", "info", "warning", "danger", ""]:
             style = "primary"
+        self.hidden = hidden
 
         if WidgetsManager.widget_exists(self.code_uid):
             self.button = WidgetsManager.get_widget(self.code_uid)
             self.button.description = label
             self.button.button_style = style
+            self.button.disabled = disabled
         else:
-            self.button = ipywidgets.Button(description=label, button_style=style)
+            self.button = ipywidgets.Button(description=label, button_style=style, disabled=disabled)
             self.button.value = False
 
             def on_button_clicked(b):
@@ -57,9 +59,16 @@ class Button:
                 "value": False,
                 "model_id": self.button.model_id,
                 "code_uid": self.code_uid,
+                "disabled": self.button.disabled,
+                "hidden": self.hidden
             }
             data["application/mercury+json"] = json.dumps(view, indent=4)
             if "text/plain" in data:
                 del data["text/plain"]
 
+            if self.hidden:
+                key = 'application/vnd.jupyter.widget-view+json'
+                if key in data:
+                    del data[key]
+
             return data
