@@ -1,6 +1,8 @@
 import json
 import os
 import tempfile
+import atexit
+import shutil
 
 import ipywidgets
 from IPython.display import display
@@ -9,15 +11,19 @@ from .manager import WidgetsManager
 
 
 class File:
-    def __init__(self, label="File upload", max_file_size="100MB"):
+    def __init__(self, label="File upload", max_file_size="100MB", disabled=False, hidden=False):
         self.max_file_size = max_file_size
         self.code_uid = WidgetsManager.get_code_uid("File")
+        self.temp_dir = None
+        atexit.register(self.cleanup)
+        self.hidden = hidden
 
         if WidgetsManager.widget_exists(self.code_uid):
             self.file = WidgetsManager.get_widget(self.code_uid)
             self.file.description = label
+            self.file.disabled = disabled
         else:
-            self.file = ipywidgets.FileUpload(description=label)
+            self.file = ipywidgets.FileUpload(description=label, disabled=disabled)
             self.file.filepath = None
             self.file.filename = None
             WidgetsManager.add_widget(self.file.model_id, self.code_uid, self.file)
@@ -31,7 +37,7 @@ class File:
         if self.file.filepath is not None:
             # read that file
             with open(
-                self.file.filepath, "rb", encoding="utf-8", errors="ignore"
+                self.file.filepath, "rb"
             ) as fin:
                 return fin.read()
 
@@ -57,8 +63,8 @@ class File:
         ):
             # store file in temp dir
             # and return the path
-            temp_dir = tempfile.TemporaryDirectory()
-            self.file.filepath = os.path.join(temp_dir.name, self.filename)
+            self.temp_dir = tempfile.mkdtemp()
+            self.file.filepath = os.path.join(self.temp_dir, self.filename)
 
             with open(self.file.filepath, "wb") as fout:
                 fout.write(self.value)
@@ -66,6 +72,11 @@ class File:
             return self.file.filepath
 
         return None
+    
+    def cleanup(self):
+        if self.temp_dir is not None and os.path.exists(self.temp_dir):
+            shutil.rmtree(self.temp_dir, ignore_errors=True)
+
 
     @value.setter
     def value(self, v):
@@ -92,9 +103,16 @@ class File:
                 "label": self.file.description,
                 "model_id": self.file.model_id,
                 "code_uid": self.code_uid,
+                "disabled": self.file.disabled,
+                "hidden": self.hidden
             }
             data["application/mercury+json"] = json.dumps(view, indent=4)
             if "text/plain" in data:
                 del data["text/plain"]
 
+            if self.hidden:
+                key = 'application/vnd.jupyter.widget-view+json'
+                if key in data:
+                    del data[key]
+
             return data
